pm4py.algo.evaluation package
=============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.evaluation.earth_mover_distance
   pm4py.algo.evaluation.generalization
   pm4py.algo.evaluation.precision
   pm4py.algo.evaluation.replay_fitness
   pm4py.algo.evaluation.simplicity

Submodules
----------

pm4py.algo.evaluation.algorithm module
--------------------------------------

.. automodule:: pm4py.algo.evaluation.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.evaluation.evaluator module
--------------------------------------

.. automodule:: pm4py.algo.evaluation.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.evaluation
   :members:
   :undoc-members:
   :show-inheritance:
